pub struct VestingStrategy {
pub discriminator: [u8; 8],
pub version: u16,
pub strategy: u8,
pub locked_shares: u64,
pub unlock_rate: u64,
pub unlock_period: u16,
pub lock_timestamp: u64,
pub cliff: u16,
pub reserved: [u8; 62],
}Fields
discriminator: [u8; 8]version: u16Struct version
strategy: u8Vesting strategy (not used, should be zero)
The amount of locked shares
unlock_rate: u64The amount of shares to unlock per lock period
unlock_period: u16The token unlock period in hours, after which N tokens will be unlocked.
lock_timestamp: u64The timestamp when the position has been locked
cliff: u16The period in hours after which the unlock starts. The first unlock occurs after ‘cliff + unlock_period’.
reserved: [u8; 62]Reserved
Implementations