pub struct SetTreasuryFlagsInstructionArgs {
pub flags: u32,
}Fields
flags: u32Trait Implementations
Sourceimpl BorshDeserialize for SetTreasuryFlagsInstructionArgswhere
u32: BorshDeserialize,
impl BorshDeserialize for SetTreasuryFlagsInstructionArgswhere
u32: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for SetTreasuryFlagsInstructionArgswhere
u32: BorshSerialize,
impl BorshSerialize for SetTreasuryFlagsInstructionArgswhere
u32: BorshSerialize,
Sourceimpl Clone for SetTreasuryFlagsInstructionArgs
impl Clone for SetTreasuryFlagsInstructionArgs
Sourcefn clone(&self) -> SetTreasuryFlagsInstructionArgs
fn clone(&self) -> SetTreasuryFlagsInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Eq for SetTreasuryFlagsInstructionArgs
impl StructuralPartialEq for SetTreasuryFlagsInstructionArgs