pub struct SetVestingStrategyInstructionArgs {
pub locked_shares: u64,
pub unlock_period: u16,
pub unlock_rate: u64,
pub cliff: u16,
}Fields
unlock_period: u16unlock_rate: u64cliff: u16Trait Implementations
Sourceimpl BorshDeserialize for SetVestingStrategyInstructionArgs
impl BorshDeserialize for SetVestingStrategyInstructionArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for SetVestingStrategyInstructionArgs
impl Clone for SetVestingStrategyInstructionArgs
Sourcefn clone(&self) -> SetVestingStrategyInstructionArgs
fn clone(&self) -> SetVestingStrategyInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for SetVestingStrategyInstructionArgs
impl PartialEq for SetVestingStrategyInstructionArgs
Sourcefn eq(&self, other: &SetVestingStrategyInstructionArgs) -> bool
fn eq(&self, other: &SetVestingStrategyInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for SetVestingStrategyInstructionArgs
impl StructuralPartialEq for SetVestingStrategyInstructionArgs