pub struct CreateTreasuryInstructionArgs {
pub reward_token_mint: Pubkey,
pub admin_authority: Pubkey,
pub swap_authority: Pubkey,
}Fields
reward_token_mint: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for CreateTreasuryInstructionArgswhere
Pubkey: BorshDeserialize,
impl BorshDeserialize for CreateTreasuryInstructionArgswhere
Pubkey: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for CreateTreasuryInstructionArgswhere
Pubkey: BorshSerialize,
impl BorshSerialize for CreateTreasuryInstructionArgswhere
Pubkey: BorshSerialize,
Sourceimpl Clone for CreateTreasuryInstructionArgs
impl Clone for CreateTreasuryInstructionArgs
Sourcefn clone(&self) -> CreateTreasuryInstructionArgs
fn clone(&self) -> CreateTreasuryInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for CreateTreasuryInstructionArgs
impl PartialEq for CreateTreasuryInstructionArgs
Sourcefn eq(&self, other: &CreateTreasuryInstructionArgs) -> bool
fn eq(&self, other: &CreateTreasuryInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CreateTreasuryInstructionArgs
impl StructuralPartialEq for CreateTreasuryInstructionArgs